package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Jun 11, 2026
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func SetLevel(level Level)
Setup installs a text slog handler on stdout. Call once before Start.
Level aliases slog.Level so callers don't need to import log/slog directly.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.